pub enum RoomKeyContent {
MegolmV1AesSha2(Box<MegolmV1AesSha2Content>),
Unknown(UnknownRoomKey),
}Expand description
The m.room_key event content.
This is an enum over the different room key algorithms we support. The
currently-supported implementations are used to share
InboundGroupSessions.
This event type is used to exchange keys for end-to-end encryption. Typically, it is encrypted as an m.room.encrypted event, then sent as a to-device event.
See https://spec.matrix.org/v1.13/client-server-api/#mroom_key.
Variants
MegolmV1AesSha2(Box<MegolmV1AesSha2Content>)
The m.megolm.v1.aes-sha2 variant of the m.room_key content.
Unknown(UnknownRoomKey)
An unknown and unsupported variant of the m.room_key content.
Implementations
Sourceimpl RoomKeyContent
impl RoomKeyContent
Sourcepub fn algorithm(&self) -> EventEncryptionAlgorithm
pub fn algorithm(&self) -> EventEncryptionAlgorithm
Get the algorithm of the room key.